@@ -146,8 +146,8 @@ class HyperV:
             return False
                 
         r_result = {}
-        r = re.findall(r"-\r\n([\w\W]*)", result.std_out.decode('utf-8'))[0]
-        for line in r.splitlines():
+        r = re.findall(r"[\s-]+\r\n([\w\W]*$)", result.std_out.decode('utf-8'))
+        for line in r[0].splitlines():
             if line:
                 r_result.setdefault(line.split()[0], dict(zip(state_keys, (line.split()[1:5]))))
         return r_result
@@ -184,8 +184,9 @@ class HyperV:
             return False
         return True
     
-    # Список снапшотов фиртуалных машин 
+    # Список снапшотов виртуалных машин 
     def snapshot_get_all(self, vms=[]):
+        state_keys = ['name', 'type', 'creation_date', 'creation_time', 'parent_snapshot' ]
         ps_script = self.gen_job(vms_list=vms, job='Get-VM', get_snapshot = True)
         result = self.session.run_ps(ps_script)
         logging.debug(f"result std_out: {result.std_out.decode('utf-8')}")
@@ -194,9 +195,11 @@ class HyperV:
             return False
         
         r_result = {}
-        for line in result.std_out.decode('utf-8').splitlines():
-            if line and not 'VMName' in line and not '------' in line:
-                r_result.setdefault(line.split()[0], []).append(line.split()[1:])
+        r = re.findall(r"[\s-]+\r\n([\w\W]*$)", result.std_out.decode('utf-8'))
+        for line in r[0].splitlines():
+            if line:
+                # r_result.setdefault(line.split()[0], []).append(line.split()[1:])
+                r_result.setdefault(line.split()[0], []).append(dict(zip(state_keys, (line.split()[1:]))))
         return r_result
 
     # Получить текущие снапшоты виртуальных машин
